"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateUser = exports.getUserById = exports.getUser = exports.createUser = void 0;
const user_model_1 = __importDefault(require("../models/user.model"));
const dotenv_1 = __importDefault(require("dotenv"));
dotenv_1.default.config();
const createUser = (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { name, surname, socialHandle, email, password, travelId, followers, following, bio } = req.body;
        if (!name || !surname || !socialHandle || !email || !password) {
            res.status(400).json({ message: 'Missing required fields' });
            return;
        }
        const profilePicture = req.file
            ? `${process.env.APIURL}/uploads/profilePictures/${req.file.filename}`
            : undefined;
        const newUser = new user_model_1.default({
            name,
            surname,
            socialHandle,
            email,
            password,
            profilePicture,
            travelId,
            followers,
            following,
            bio,
        });
        const savedUser = yield newUser.save();
        //console.log(savedUser);
        res.status(201).json(savedUser);
    }
    catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
});
exports.createUser = createUser;
const getUser = (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const user = yield user_model_1.default.find();
        res.status(200).json(user);
    }
    catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
});
exports.getUser = getUser;
const getUserById = (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const user = yield user_model_1.default.findById(req.params.userId);
        res.status(200).json(user);
    }
    catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
});
exports.getUserById = getUserById;
const updateUser = (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const updatedUser = yield user_model_1.default.findByIdAndUpdate(req.params.userId, req.body, { new: true });
        res.status(200).json(updatedUser);
    }
    catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
});
exports.updateUser = updateUser;
