import express, { Request, Response } from 'express';
const app = express();
import cors from 'cors';
import consts from './consts';
import bodyParser from 'body-parser';
import authenticateToken from './token';
import jwt from 'jsonwebtoken';
import * as bridge from './bridge';
require('dotenv').config();
import path from 'path';
import mongoose from "mongoose";
import userRouter from './routes/user.routes';
import friendRoutes from './routes/friends.routes';
import reisenRoutes from "./routes/reisen.routes";
import postsRoutes from "./routes/posts.routes";
import {getKeycloak, getMemoryStore} from './middleware/keycloak.mw';
import session from "express-session";

const keycloak = getKeycloak();
const memoryStore = getMemoryStore();

app.use(session({
    secret: '§!/)Z)UDJUIKendukdne!§!"§',
    resave: false,
    saveUninitialized: true,
    store: memoryStore,
}));

// aktiviere keycloak
app.use(keycloak.middleware());

const DBURL = process.env.DBURL;
const INITTIME = new Date();
if (!DBURL) {
    console.log("No DBURL found in .env file");
    process.exit(1);
} else {
    mongoose.connect(DBURL)
        .then(() => {
            console.log('Connected to database!');
        })
        .catch(() => {
            console.log('Connection failed!');
        });
}


app.use(
    cors({
        origin: "*"
    })
)
app.use(bodyParser.json());

/////////////////////////////////////////////////////////////////////
//                          Config-End
/////////////////////////////////////////////////////////////////////

//start tests
app.get("/connectionTest", async (req: Request, res: Response) => {
    await bridge.connectionTest(res, req);
});

app.get("/connectionAuthTest", authenticateToken, async (req: Request, res: Response) => {
    await bridge.connectionAuthTest(res, req);
});
app.get("/getAPIStartTimeStamp", async (req: Request, res: Response) => {

    const germanDate = INITTIME.toLocaleString('de-DE', {
        day: '2-digit',
        month: '2-digit',
        year: 'numeric',
        hour: '2-digit',
        minute: '2-digit',
        second: '2-digit',
        timeZone: 'Europe/Berlin'
    });

    return res.json({apistarttime: germanDate});
});

app.use('/user', userRouter);
app.use('/uploads', express.static(path.resolve(__dirname, '../uploads/')));
app.use('/friend', friendRoutes);
app.use('/reisen', reisenRoutes);
app.use('/posts', postsRoutes);

console.log("Main-API-Port: " + consts.api_port);
app.listen(consts.api_port);
