import { Request, Response } from 'express';
import Reise from '../models/reisen.model';
import { IReise } from '../models/reisen.model';
import dotenv from 'dotenv';
import User from "../models/user.model";
import Post from "../models/posts.model";
dotenv.config();

export const createReise = async (req: Request, res: Response): Promise<void> => {
    try {
        const { name, location, startDate, endDate, userId } = req.body;
        console.log(req.body)


        if (!name || !location || !startDate || !endDate || !userId) {
            res.status(400).json({ message: 'Missing required fields' });
            return;
        }

        if (!req.file) {
            res.status(400).json({ message: 'Missing picture' });
            return;
        }
        const locationObj = JSON.parse(location);
        const imageUrl = req.file.path.split("travelpicapi")[1];
        let imagePaths: string[] = [];
        imagePaths.push("https://api.travelpic.app" + imageUrl);

        const newReise: IReise = new Reise({
            name,
            location: {
                lat: locationObj.lat,
                lon: locationObj.lon
            },
            startDate,
            endDate,
            userId,
            pictures: imagePaths
        });

        console.log("Not saved",newReise);
        const savedReise = await newReise.save();
        console.log(savedReise);
        res.status(201).json(savedReise);
    } catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
};

export const getReisenByUserId = async (req: Request, res: Response): Promise<void> => {
    try {
        const userId = req.params.userId;
        const reisen = await Reise.find({ userId });
        res.status(200).json(reisen);
    } catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
}

export const getAvailableReisen = async (req: Request, res: Response): Promise<void> => {
    try {
        const userId = req.params.userId;

        // Fetch the user to get the list of users they are following
        const user = await User.findOne({kc_id: userId});

        if (!user) {
            res.status(404).json({ message: 'User not found' });
            return;
        }

        const following = user.following || [];

        // Include the user's own ID in the list of IDs to fetch trips for
        const userIds = [userId, ...following];

        // Fetch all reisen where the userId is in the list of user IDs
        const reisen = await Reise.find({ userId: { $in: userIds } });

        res.status(200).json(reisen);
    } catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
};

export const deleteReise = async (req: Request, res: Response): Promise<void> => {
    try {
        const reiseId = req.params.reiseId;
        await Reise.findByIdAndDelete(reiseId);
        await Post.deleteMany({ reiseid: reiseId });
        res.status(204).send();
    } catch (err) {
        res.status(500).json({ message: err instanceof Error ? err.message : 'An error occurred' });
    }
};
