import { Request, Response, NextFunction } from 'express';

interface KeycloakGrant {
    access_token: {
        token: string;
        content: {
            preferred_username: string;
            realm_access: {
                roles: string[];
            };
        };
    };
}

interface KeycloakRequest extends Request {
    kauth: {
        grant: KeycloakGrant;
    };
}

function checkRole(role: string) {
    return function(req: KeycloakRequest, res: Response, next: NextFunction) {
        const accessToken = req.kauth.grant.access_token.token;
        const username = req.kauth.grant.access_token.content.preferred_username;
        const userRoles = req.kauth.grant.access_token.content.realm_access.roles;

        if (userRoles.includes(role)) {
            next(); // Role is correct, continue
        } else {
            res.status(403).send('Access denied'); // Role doesn't match, send access denied
        }
    };
}

export default checkRole;
