import User from "../models/user.model";
import { IUser } from "../models/user.model";
import { NextFunction, Request, Response } from "express";
import { jwtDecode } from "jwt-decode";

interface KeycloakToken {
    sub: string;
    exp: number;
    iat: number;
}

export const isCorrectUser = async (req: Request, res: Response, next: NextFunction): Promise<void> => {
    try {
        if (!req.headers.authorization || !req.headers.authorization.startsWith('Bearer ')) {
            res.status(401).json({ message: "Not authenticated" });
            return;
        }

        const token = req.headers.authorization.split(' ')[1];

        let decodedToken: KeycloakToken;
        try {

            decodedToken = jwtDecode<KeycloakToken>(token);
        } catch (err) {
            res.status(401).json({ message: "Invalid token" });
            return;
        }

        // Extract the subject (user ID) from the token
        const sub = decodedToken.sub;

        // Find the user by the provided userId from params
        const user: IUser | null = await User.findOne({ kc_id: req.params.userId });
        if (!user) {
            res.status(404).json({ message: "User not found" });
            return;
        }

        // Check if the userId in the token (sub) matches the kc_id in the database
        if (user.kc_id === sub) {
            // User is authorized to access this resource
            next();
        } else {
            res.status(403).json({ message: "You are not allowed to access this user" });
        }
    } catch (err) {
        // Handle general errors
        res.status(500).json({ message: err instanceof Error ? err.message : "An internal server error occurred" });
    }
};
