import multer from 'multer';
import path from 'path';
import sharp from 'sharp';
import fs from 'fs';
import {NextFunction} from "express";

const storage = multer.diskStorage({
    destination: (req, file, cb) => {
        cb(null, path.resolve('./uploads/profilePictures'));
    },
    filename: (req, file, cb) => {
        cb(null, `${file.fieldname}-${Date.now()}${path.extname(file.originalname)}`);
    }
});

const upload = multer({
    storage: storage,
    limits: { fileSize: 1000000000 },
    fileFilter: (req, file, cb) => {
        const filetypes = /jpeg|jpg|png/;
        const extname = filetypes.test(path.extname(file.originalname).toLowerCase());
        const mimetype = filetypes.test(file.mimetype);

        if (mimetype && extname) {
            return cb(null, true);
        } else {
            cb(new Error('Only JPEG, JPG, or PNG files are allowed!'));
        }
    }
});

const compressImages = async (req: any, res: any, next: any) => {
    if (!req.files || !Array.isArray(req.files)) return next();

    try {
        await Promise.all(
            req.files.map(async (file: any) => {
                const filePath = file.path;
                const compressedFilePath = path.resolve('./uploads/profilePictures', `compressed-${file.filename}`);

                await sharp(filePath)
                    .rotate()
                    .resize(1000)
                    .withMetadata()
                    .toFormat('jpeg')
                    .jpeg({ quality: 70 })
                    .toFile(compressedFilePath);

                fs.unlinkSync(filePath);

                file.path = compressedFilePath;
                file.filename = `compressed-${file.filename}`;
            })
        );

        next();
    } catch (error) {
        next(error);
    }
};

export { upload, compressImages };
