import express from 'express';
import {
    addProfilePicture,
    createKeycloakUser,
    createUser,
    getUser,
    getUserById,
    updateUser,
    getUserPublicInformationById,
    searchUserByUsernamechunk, getFollowers, getFollowing
} from '../controller/user.controller';
import {upload} from '../middleware/multer.mw';
import { getKeycloak} from "../middleware/keycloak.mw";
import {isCorrectUser} from "../middleware/isCorrectUser.mw";

const Keycloak = getKeycloak();

const router = express.Router();

// router.post('/createUser', upload.single('profilePicture'), createUser);

router.post('/createKeycloakUser', Keycloak.protect(), createKeycloakUser);

router.get('/getUser', Keycloak.protect(), getUser);

router.get('/getUserById/:userId', Keycloak.protect(), isCorrectUser, getUserById);

router.get('/getFollowers', Keycloak.protect(), getFollowers);

router.get('/getFollowing', Keycloak.protect(), getFollowing);

router.put('/updateUser/:userId', upload.single('profilePicture'), updateUser);

router.post('/addProfilePicture/:userId', Keycloak.protect(), isCorrectUser, upload.single('profilePicture'), addProfilePicture);

router.get('/getUserPublicInformationById/:userId', Keycloak.protect(), getUserPublicInformationById);

router.get('/searchUserByUsernamechunk/:unameChunk', Keycloak.protect(), searchUserByUsernamechunk);


export default router;
